*-------------------------------------------------------------------------------------*
* Note: Run 01_preparation.do before running this dofile                              *
*-------------------------------------------------------------------------------------*

*-------------------------------------------------------------------------------------*
* Configuration                                                                       *
* ------------------------------------------------------------------------------------*

*-------------------------------- specify your path here! ----------------------------*

* Set path to working directory
global dir 			"_SET_PATH_HERE_"

*-------------------------------------------------------------------------------------*

global data			"${dir}/02_data"
global tables		"${dir}/03_tables"
global graphs 		"${dir}/04_graphs"


*-------------------------------------------------------------------------------------*
use "${data}/data", clear
*-------------------------------------------------------------------------------------*

*-------------------------------------------------------------------------------------*
* Table 1																			  *
*-------------------------------------------------------------------------------------*

* Generate auxiliary variables for description
tab church, gen(church)
tab relig, gen(relig)
tab pmic, gen(inc)
clonevar aux = why
replace aux = . if aux == 3
tab aux, gen(why)
	drop aux
egen pick = tag(pid)

* Generate random variable for episodes in control sample
capture drop n
bysort pid (syear): gen n = _n
	preserve
		sample 1, by(pid) count
		keep pid n
		save "${data}/randomep", replace
	restore
merge 1:1 pid n using "${data}/randomep", keep(1 3)
gen random = _merge == 3
drop _merge

* Descriptives on gender
tab male event if pick == 1 & mig == 0, col
tab male event if pick == 1 & mig == 1, col

* Other descriptives
capture drop n
bysort pid (syear): gen n = _n
	// Natives, event sample
		sum ls if n == 1 & event == 1 & mig == 0
		/// Measured across all observations	
		tabstat age inc? par d11106 size  if event == 1 & mig == 0, ///
			stats(mean sd min max) col(stat) format(%9.2f)
		/// Measured in the year before unemployment
		tabstat	hw_trad child mar church? own if before == 1 & event == 1 & mig == 0, ///
			stats(mean sd min max) col(stat) format(%9.2f)	
		/// Measured in the year of unemployment
		tabstat age_tr yue why? gdp if time == 1 & mig == 0, ///
			stats(mean sd min max) col(stat) format(%9.2f)
	// Natives, control sample
		sum ls if n == 1 & event == 0 & mig == 0
		/// Measured across all observations	
		tabstat age inc? par d11106 size  if event == 0 & mig == 0, ///
			stats(mean sd min max) col(stat) format(%9.2f)
		/// Measured at random episode
		tabstat	trad child married relig? owner if random == 1 & event == 0 & mig == 0, ///
			stats(mean sd min max) col(stat) format(%9.2f)	
	// Immigrants, event sample
		sum ls if n == 1 & event == 1 & mig == 1
		/// Measured across all observations	
		tabstat age inc? par d11106 size  if event == 1 & mig == 1, ///
			stats(mean sd min max) col(stat) format(%9.2f)
		/// Measured in the year before unemployment
		tabstat	hw_trad child mar church? own if before == 1 & event == 1 & mig == 1, ///
			stats(mean sd min max) col(stat) format(%9.2f)	
		/// Measured in the year of unemployment
		tabstat age_tr yue why? gdp if time == 1 & mig == 1, ///
			stats(mean sd min max) col(stat) format(%9.2f)
	// Immigrants, control sample
		sum ls if n == 1 & event == 0 & mig == 0
		/// Measured across all observations	
		tabstat age inc? par d11106 size  if event == 0 & mig == 1, ///
			stats(mean sd min max) col(stat) format(%9.2f)
		/// Measured at random episode
		tabstat	trad child married relig? owner if random == 1 & event == 0 & mig == 1, ///
			stats(mean sd min max) col(stat) format(%9.2f)	

* Countries of origin
tab origin_group if mig == 1 & event == 1 & pick == 1, m
tab origin_group if mig == 1 & event == 0 & pick == 1, m


*-------------------------------------------------------------------------------------*
* Table 2					    													  *
*-------------------------------------------------------------------------------------*

* Set to panel data
xtset pid syear


* Model 1: Time + controls
xtreg 	ls 						///
		i.time					///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M1	

* Model 2: Time x Mig + controls	
xtreg 	ls 						///
		i.time##i.mig			///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M2	

* Model 3: Time x Mig + Time x Male + controls	
xtreg 	ls 						///
		i.time##i.mig			///
		i.time##i.male			///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M3	

* Model 4: Time x Mig + Time x Male + Time x Mig x Male + controls	
xtreg 	ls 						///
		i.time##i.mig##i.male	///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M4	

* Model 5: Time x Mig + Time x Male + Time x Mig x Male + Time x Role Indicators + controls	
xtreg 	ls 						///
		i.time##i.mig##i.male	///
		i.time##i.kid##i.male	///
		i.time##i.hw_trad		///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M5	

* Model 6: Time x Mig + Time x Male + Time x Mig x Male + Time x Role Indicators + Buffer + Type + controls	
xtreg 	ls 						///
		i.time##i.mig##i.male	///
		i.time##i.kid##i.male	///
		i.time##i.hw_trad		///
		i.time##i.mar			///
		i.time##i.church		///
		i.time##i.own			///
		i.time##i.why			///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M6	

* Model 7: Time x Mig + Time x Male + Time x Mig x Male + Time x Role Indicators + Buffer + Type + Mediators + controls	
xtreg 	ls 						///
		i.time##i.mig##i.male	///
		i.time##i.kid##i.male	///
		i.time##i.hw_trad		///
		i.time##i.mar			///
		i.time##i.church		///
		i.time##i.own			///
		i.time##i.why			///
		i.pmic					///
		ib1.par					///
		c.size_c				///
		c.size2_c				///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store M7

* Table 2
outreg2 [M1 M2 M3 M4 M5 M6 M7] using "${tables}/table_2", side word excel replace cti(b) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("R-squared", e(r2), "N (observations)", e(N))
est clear


*-------------------------------------------------------------------------------------*
* Figure 1					    													  *
*-------------------------------------------------------------------------------------*
			
* Plot results from Model 7

capture drop ls1
gen ls1 = ls - 7.124984 // substract to get contrast effects starting from 0

xtreg 	ls1 					///
		i.time##i.mig##i.male	///
		i.time##i.kid##i.male	///
		i.time##i.hw_trad		///
		i.time##i.mar			///
		i.time##i.church		///
		i.time##i.own			///
		i.time##i.why			///
		i.pmic					///
		ib1.par					///
		c.size_c				///
		c.size2_c				///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
	
margins time,						///
	at  (mig=(0) male=(0)) 			///
	at  (mig=(1) male=(0)) 			///
	at  (mig=(0) male=(1)) 			///
	at  (mig=(1) male=(1)) 			///
	atmeans vsquish noestimcheck

marginsplot,    plot1opts(msymbol(D) mcolor(black) lcolor(black) lpattern(solid)) 		///
				plot2opts(msymbol(D) mcolor(black) lcolor(black) lpattern(shortdash))	///
				plot3opts(msymbol(T) mcolor(black) lcolor(black) lpattern(solid)) 		///
				plot4opts(msymbol(T) mcolor(black) lcolor(black) lpattern(shortdash))  	///
            title ("", size(small) color(black))     					///
            ytitle("Decline in Subjective Well-Being", size(small)) 	///
            ylab (0 (0.1) -1, labsize(small) angle(0) format(%9.1f))	///
            xtitle("Number of Years Unemployed", size(small))       	///
            xscale(titlegap(2)) xlab (, labsize(small))     			///
			legend(off) noci   											///
			graphregion(color(white) fcolor(white) icolor(white)) 		///
			saving("${graphs}/figure_1.gph", replace)

			
*-------------------------------------------------------------------------------------*
* Additional analyses (supplement) 													  *
*-------------------------------------------------------------------------------------*

* Additional explanatory factors

sum age_tr if ue
gen age_tr_c = age_tr - r(mean)
replace age_tr_c = 0 if age_tr_c == .
gen rec = gdp < 0

xtreg 	ls 						///
		i.time##i.mig##i.male	///
		i.time##i.kid##i.male	///
		i.time##i.hw_trad		///
		i.time##i.mar			///
		i.time##i.church		///
		i.time##i.own			///
		i.time##i.why			///
		i.pmic					///
		ib1.par					///
		c.size_c				///
		c.size2_c				///
		i.time##c.age_tr_c		///
		i.time##i.edu			///
		i.time##i.rec			///
		i.srh					///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe

est store add_var

** Table A1
outreg2 [add_var] using "${tables}/table_A1", side word excel replace cti(b) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("R-squared", e(r2), "N (observations)", e(N))

est clear


* Attrition analysis

tab left mig if pick == 1 & event == 1, col
tab left mig if pick == 1 & event == 0, col

xtreg 	ls 						///
		i.time##i.mig##i.left	///
		if male == 1, fe

est store attrition

** Table A2
outreg2 [attrition] using "${tables}/table_A2", side word excel replace cti(b) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("R-squared", e(r2), "N (observations)", e(N))

est clear		


* Endogeneity of unemployment duration to SWB

** Lead effects			
gen ls2 = ls - 7.132159 
xtreg 	ls2	 					///
		i.time1##i.mig##i.male	///
		c.age_c##i.mig			///
		c.age2_c##i.mig			///
		c.age3_c##i.mig			///
		c.age4_c##i.mig			///
		c.gdp					///
	, fe
est store endo1

** Table A3
outreg2 [endo1] using "${tables}/table_A3", side word excel replace cti(b) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("R-squared", e(r2), "N (observations)", e(N))

** Figure A1			
margins time1,						///
	at  (mig=(0) male=(0)) 			///
	at  (mig=(1) male=(0)) 			///
	at  (mig=(0) male=(1)) 			///
	at  (mig=(1) male=(1)) 			///
	atmeans vsquish noestimcheck
marginsplot,    plot1opts(msymbol(D) mcolor(black) lcolor(black) lpattern(solid)) 		///
				plot2opts(msymbol(D) mcolor(black) lcolor(black) lpattern(shortdash))	///
				plot3opts(msymbol(T) mcolor(black) lcolor(black) lpattern(solid)) 		///
				plot4opts(msymbol(T) mcolor(black) lcolor(black) lpattern(shortdash))  	///
            title ("", size(small) color(black))     					///
            ytitle("Decline in Subjective Well-Being", size(small)) 	///
            ylab (0 (0.1) -1, labsize(small) angle(0) format(%9.1f))	///
            xtitle("Number of Years Unemployed", size(small))       	///
            xscale(titlegap(2)) xlab (, labsize(small))     			///
			legend(off) noci   											///
			graphregion(color(white) fcolor(white) icolor(white)) 		///
			saving("${graphs}/figure_A1.gph", replace)

** Life satisfaction in year before unemployment
gen aux = ls if before == 1
bysort pid: egen lsb = max(aux)
	drop aux
	
** Life satisfaction in year of unemployment
gen aux = ls if time == 1
bysort pid: egen lsu = max(aux)
	drop aux

** Drop in life satisfaction
gen lsdrop = lsb - lsu

** Compare duration of unemployment 
sum dur_ue if pick & event & mig == 0 
sum dur_ue if pick & event & mig == 1 
sum dur_ue if pick & event 

** Case numbers across the duration of unemployment	
distinct pid if time==1
distinct pid if time==2
distinct pid if time==3
distinct pid if !mig & time==1
distinct pid if !mig & time==2
distinct pid if !mig & time==3
	dis 1639/4387
	dis 357/2237
distinct pid if mig & time==1
distinct pid if mig & time==2
distinct pid if mig & time==3
	dis 328/888
	dis 194/888

** Dichotomous duration variables
gen dur_ue2 = dur_ue > 1 & dur_ue < .
gen dur_ue3 = dur_ue > 2 & dur_ue < .

** SWB before unemployment by duration of unemployment
sum lsb if event == 1 & mig == 0 & male == 1 & index == 0
sum lsb if event == 1 & mig == 0 & male == 1 & index == 1
sum lsb if event == 1 & mig == 0 & male == 1 & index == 2
sum lsb if event == 1 & mig == 1 & male == 1 & index == 0
sum lsb if event == 1 & mig == 1 & male == 1 & index == 1
sum lsb if event == 1 & mig == 1 & male == 1 & index == 2				

** Regress duration of unemployment on SWB			
reg  dur_ue c.lsb##i.mig c.lsdrop##i.mig if pick & event & male==1
est store endo2
reg  dur_ue2 c.lsb##i.mig c.lsdrop##i.mig if pick & event & male==1
est store endo3 
reg  dur_ue3 c.lsb##i.mig c.lsdrop##i.mig if pick & event & male==1
est store endo4

** Table A4	
outreg2 [endo2 endo3 endo4] using "${tables}/table_A4", side word excel replace cti(b) dec(2) ///
alpha(.001, .01, .05, .10) symbol(***, **, *, +) noobs drop(*b. 99* *miss) ///
adds("R-squared", e(r2), "N (observations)", e(N))
			


			


			
